@@ -1,3 +1,4 @@
+import os
 from functools import wraps
 from typing import Callable, Any
 
@@ -15,8 +16,8 @@ Decorator = Callable[[HttpRequest], HttpResponse]
 def authenticated(func: Callable[[Player, HttpRequest], BaseModel]):
     @wraps(func)
     def wrapper(request: HttpRequest):
-        access_token = request.headers[access_header]
-        client_token = request.headers[client_header]
+        access_token = request.headers.get(access_header)
+        client_token = request.headers.get(client_header)
         if not all((access_header, client_header)):
             raise HttpResponseForbidden
 
